History
=======

## v0.5.1
* Fixed community creations dyncamic import.
* Added extras_requires in pip install.

## v0.5.0 (2022-04-08)
* Added support for [allianceauth-pve](https://github.com/Maestro-Zacht/allianceauth-pve) package.

## v0.4.0 (2022-04-06)
* Implemented the 3 steps registration.

## v0.3.1 (2022-04-05)
* Fixed wrong id reference in addCharacter mutation.

## v0.3.0 (2022-04-05)
Implemented all the views in the authentication app:
* Change main character
* Add a character
* User's groups
* User's alts

## v0.2.1 (2022-04-04)
* Updated history and readme, no change to the code.

## v0.2.0 (2022-04-04)
* Working login with django-graphql-jwt.
## v0.1.1 (2022-04-02)
* Working /graphql/ endpoint and updated requirements.

## v0.1.0 (2022-03-18)
* First release on PyPI.